@@ -27,14 +27,19 @@
 #ifndef INCLUDED_CMDUNDO
 #define INCLUDED_CMDUNDO
 
-#include <string>
 #include <Command.h>
+#include <Operation.h>
 
-class CmdUndo : public Command
-{
-public:
-  CmdUndo ();
-  int execute (std::string&);
+#include <string>
+#include <vector>
+
+class CmdUndo : public Command {
+ public:
+  CmdUndo();
+  int execute(std::string&);
+
+ private:
+  bool confirm_revert(const std::vector<Operation>&);
 };
 
 #endif
