@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
+// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -20,15 +20,14 @@
 // OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// http://www.opensource.org/licenses/mit-license.php
+// https://opensource.org/license/mit
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Duration.h>
-#include <unicode.h>
-#include <sstream>
 #include <iomanip>
+#include <sstream>
+#include <unicode.h>
 #include <vector>
 
 bool Duration::standaloneSecondsEnabled = true;
@@ -307,7 +306,7 @@ bool Duration::parse_units (Pig& pig)
 
   // Static and so preserved between calls.
   static std::vector <std::string> units;
-  if (units.size () == 0)
+  if (units.empty ())
     for (unsigned int i = 0; i < NUM_DURATIONS; i++)
       units.push_back (durations[i].unit);
 
@@ -396,7 +395,7 @@ void Duration::clear ()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string Duration::format () const
+std::string Duration::format () const
 {
   if (_period)
   {
@@ -425,7 +424,7 @@ const std::string Duration::format () const
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string Duration::formatHours () const
+std::string Duration::formatHours () const
 {
   if (_period)
   {
@@ -450,7 +449,7 @@ const std::string Duration::formatHours () const
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string Duration::formatISO () const
+std::string Duration::formatISO () const
 {
   if (_period)
   {
@@ -491,7 +490,7 @@ const std::string Duration::formatISO () const
 // >= 1min    {n}min
 //            {n}s
 //
-const std::string Duration::formatVague (bool padding) const
+std::string Duration::formatVague (bool padding) const
 {
   float days = (float) _period / 86400.0;
 
