@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2013 - 2021, Göteborg Bit Factory.
+// Copyright 2016 - 2021, 2023, Gothenburg Bit Factory.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -20,16 +20,14 @@
 // OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// http://www.opensource.org/licenses/mit-license.php
+// https://opensource.org/license/mit
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <cmake.h>
 #include <Lexer.h>
 #include <iostream>
-#include <vector>
-#include <string.h>
 #include <test.h>
+#include <vector>
 
 ////////////////////////////////////////////////////////////////////////////////
 int main (int, char**)
@@ -60,7 +58,7 @@ int main (int, char**)
   while (l3.token (token, type))
   {
     std::cout << "# «" << token << "» " << Lexer::typeName (type) << '\n';
-    tokens.push_back (std::pair <std::string, Lexer::Type> (token, type));
+    tokens.emplace_back (token, type);
   }
 
   t.is ((int)tokens.size (),     7,                           "7 tokens");
