@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 import sys
 import json
@@ -13,7 +12,7 @@ task["description"] = "This is an example modify hook"
 # A random message
 sys.stdout.write("Hello from the template hook\n")
 
-sys.stdout.write(json.dumps(task, separators=(',', ':')) + '\n')
+sys.stdout.write(json.dumps(task, separators=(",", ":")) + "\n")
 sys.exit(1)
 
 # vim: ai sts=4 et sw=4
